/*
'* Project name:
'    AudioAmp click
'* Copyright:
'    (c) Mikroelektronika, 2016.
'* Revision History
'    - mikroC release (AM);
'
'* Description:
'     AudioAmp click is a mikroBUS add-on board that functions as a mono audio amplifier.
'     It is driven by a Texas Instruments LM48100Q-Q1 Boomer Mono, 1.3W Audio Power Amplifier IC.
'* Test configuration:
'    MCU:             dsPIC33FJ256GP710A
'                     http://ww1.microchip.com/downloads/en/DeviceDoc/70593d.pdf
'    dev.board:       easypic fusion v7 - 
'                     http://www.mikroe.com/easypic-fusion/
'    Oscillator:      XT-PLL, 80.000MHz
'    Ext. modules:    AudioAmp click
'    SW:              mikroC PRO for dsPIC
'                     http://www.mikroe.com/mikroc/dspic/
'* NOTES:
'    - AudioAmp click must be connected on mikroBUS socket 1.*/


/* Pins
 ******************************************************************************/
sbit AA_SCL at LATA2_bit;
sbit AA_SDA at LATA3_bit;

/* Variables
 ******************************************************************************/
#define POWER_ON                0x1C
#define VOLUME_1                0x60
#define VOLUME_2                0x80

static char dev_addr = 0xF8;

/* Prototypes
 ******************************************************************************/
void system_init();
void power_on();
void volume( char value );

/* Functions
 ******************************************************************************/
void system_init()
{
    TRISA = 0;

    AA_SDA = 0;
    AA_SCL = 0;
    AA_SDA = 1;
    AA_SCL = 1;
    Delay_ms( 300 );
    AA_SDA = 0;
    AA_SCL = 0;
    Delay_ms( 300 );

    I2C2_Init( 100000 );
    Delay_ms( 200 );
}

void power_on()
{
    I2C2_Start();
    I2C2_Write( dev_addr );
    I2C2_Write( POWER_ON );
    I2C2_Stop();
}

void volume( char value )
{
    if ( value > 0x1F )
       return;

    I2C2_Start();
    I2C2_Write( dev_addr );
    I2C2_Write( value | VOLUME_1 );
    I2C2_Stop();

    I2C2_Start();
    I2C2_Write( dev_addr );
    I2C2_Write( value | VOLUME_2 );
    I2C2_Stop();
}

/* Main
 ******************************************************************************/
void main()
{
    system_init();
    power_on();
    volume( 15 );

    while( 1 );
}